@@ -69,6 +69,13 @@ class GetOvercloudConfig(templates.ProcessTemplatesAction):
             if err.http_status != 404:
                 raise
 
+        # Delete downloaded tarball as it will be recreated later and we don't
+        # want to include the old tarball in the new tarball.
+        old_tarball_path = os.path.join(
+            self.config_dir, '%s.tar.gz' % self.container_config)
+        if os.path.exists(old_tarball_path):
+            os.unlink(old_tarball_path)
+
         config = ooo_config.Config(heat)
         message = ('Automatic commit by Mistral GetOvercloudConfig action.\n\n'
                    'User: {user}\n'
@@ -87,10 +94,9 @@ class GetOvercloudConfig(templates.ProcessTemplatesAction):
                 tmp_tarball.name,
                 self.container_config)
             # Also upload the tarball to the container for use by export later
-            with open(tmp_tarball.name) as t:
+            with open(tmp_tarball.name, 'rb') as t:
                 swift.put_object(self.container_config,
-                                 '%s.tar.gz' % self.container_config,
-                                 t.read())
+                                 '%s.tar.gz' % self.container_config, t)
         if os.path.exists(config_path):
             shutil.rmtree(config_path)
 
