@@ -17,11 +17,9 @@ import collections
 import hashlib
 import json
 import os
-import requests
 import shutil
 
 from oslo_log import log as logging
-from tripleo_common.utils import image as image_utils
 
 LOG = logging.getLogger(__name__)
 
@@ -32,12 +30,10 @@ MEDIA_TYPES = (
     MEDIA_MANIFEST_V1,
     MEDIA_MANIFEST_V1_SIGNED,
     MEDIA_MANIFEST_V2,
-    MEDIA_MANIFEST_V2_LIST,
 ) = (
     'application/vnd.docker.distribution.manifest.v1+json',
     'application/vnd.docker.distribution.manifest.v1+prettyjws',
     'application/vnd.docker.distribution.manifest.v2+json',
-    'application/vnd.docker.distribution.manifest.list.v2+json',
 )
 
 TYPE_KEYS = (
@@ -78,139 +74,82 @@ def image_tag_from_url(image_url):
 
 
 def export_stream(target_url, layer, layer_stream, verify_digest=True):
-    image, _ = image_tag_from_url(target_url)
+    image, tag = image_tag_from_url(target_url)
     digest = layer['digest']
     blob_dir_path = os.path.join(IMAGE_EXPORT_DIR, 'v2', image, 'blobs')
     make_dir(blob_dir_path)
     blob_path = os.path.join(blob_dir_path, '%s.gz' % digest)
 
-    LOG.debug('[%s] Export layer to %s' % (image, blob_path))
+    LOG.debug('export layer to %s' % blob_path)
 
     length = 0
     calc_digest = hashlib.sha256()
-
     try:
-        with open(blob_path, 'wb') as f:
-            count = 0
+        with open(blob_path, 'w+b') as f:
             for chunk in layer_stream:
-                count += 1
                 if not chunk:
                     break
-                LOG.debug('[%s] Writing chunk %i for %s' %
-                          (image, count, digest))
                 f.write(chunk)
                 calc_digest.update(chunk)
                 length += len(chunk)
-                LOG.debug('[%s] Written %i bytes for %s' %
-                          (image, length, digest))
+
+        layer_digest = 'sha256:%s' % calc_digest.hexdigest()
+        LOG.debug('Calculated layer digest: %s' % layer_digest)
+
+        if verify_digest:
+            if digest != layer_digest:
+                raise IOError('Expected digest %s '
+                              'does not match calculated %s' %
+                              (digest, layer_digest))
+        else:
+            # if the original layer is uncompressed
+            # the digest may change on export
+            expected_blob_path = os.path.join(
+                blob_dir_path, '%s.gz' % layer_digest)
+            if blob_path != expected_blob_path:
+                os.rename(blob_path, expected_blob_path)
+
     except Exception as e:
-        write_error = '[{}] Write Failure: {}'.format(image, str(e))
-        LOG.error(write_error)
+        LOG.error('Error while writing blob %s' % blob_path)
+        # cleanup blob file
         if os.path.isfile(blob_path):
             os.remove(blob_path)
-            LOG.error('[%s] Broken layer found and removed %s' %
-                      (image, blob_path))
-        raise IOError(write_error)
-    else:
-        LOG.info('[%s] Layer written successfully %s' % (image, blob_path))
-
-    layer_digest = 'sha256:%s' % calc_digest.hexdigest()
-    LOG.debug('[%s] Provided digest: %s, Calculated digest: %s' %
-              (image, digest, layer_digest))
-
-    if verify_digest:
-        if digest != layer_digest:
-            hash_request_id = hashlib.sha1(str(target_url.geturl()).encode())
-            error_msg = (
-                '[%s] Image ID: %s, Expected digest "%s" does not match'
-                ' calculated digest "%s", Blob path "%s". Blob'
-                ' path will be cleaned up.' % (
-                    image,
-                    hash_request_id.hexdigest(),
-                    digest,
-                    layer_digest,
-                    blob_path
-                )
-            )
-            LOG.error(error_msg)
-            if os.path.isfile(blob_path):
-                os.remove(blob_path)
-            raise requests.exceptions.HTTPError(error_msg)
-    else:
-        # if the original layer is uncompressed
-        # the digest may change on export
-        expected_blob_path = os.path.join(
-            blob_dir_path, '%s.gz' % layer_digest
-        )
-        if blob_path != expected_blob_path:
-            os.rename(blob_path, expected_blob_path)
-            blob_path = expected_blob_path
+        raise e
 
     layer['digest'] = layer_digest
     layer['size'] = length
-    LOG.debug('[%s] Done exporting image layer %s' % (image, digest))
-    return (layer_digest, blob_path)
+    return layer_digest
 
 
-def layer_cross_link(layer, image, blob_path, target_image_url):
-    target_image, _ = image_tag_from_url(target_image_url)
-    target_dir_path = os.path.join(
-        IMAGE_EXPORT_DIR, 'v2', target_image, 'blobs')
-    make_dir(target_dir_path)
-    target_blob_path = os.path.join(target_dir_path, '%s.gz' % layer)
-    if not os.path.exists(target_blob_path):
-        LOG.debug('[%s] Linking layers: %s -> %s' %
-                  (image, blob_path, target_blob_path))
+def cross_repo_mount(target_image_url, image_layers, source_layers):
+    for layer in source_layers:
+        if layer not in image_layers:
+            continue
+
+        image_url = image_layers[layer]
+        image, tag = image_tag_from_url(image_url)
+        dir_path = os.path.join(IMAGE_EXPORT_DIR, 'v2', image, 'blobs')
+        blob_path = os.path.join(dir_path, '%s.gz' % layer)
+        if not os.path.exists(blob_path):
+            LOG.debug('Layer not found: %s' % blob_path)
+            continue
+
+        target_image, tag = image_tag_from_url(target_image_url)
+        target_dir_path = os.path.join(
+            IMAGE_EXPORT_DIR, 'v2', target_image, 'blobs')
+        make_dir(target_dir_path)
+        target_blob_path = os.path.join(target_dir_path, '%s.gz' % layer)
+        if os.path.exists(target_blob_path):
+            continue
+        LOG.debug('Linking layers: %s -> %s' % (blob_path, target_blob_path))
         # make a hard link so the layers can have independent lifecycles
         os.link(blob_path, target_blob_path)
 
 
-def cross_repo_mount(target_image_url, image_layers, source_layers,
-                     uploaded_layers=None):
-    linked_layers = {}
-    target_image, _ = image_tag_from_url(target_image_url)
-    for layer in source_layers:
-        known_path, ref_image = image_utils.uploaded_layers_details(
-            uploaded_layers, layer, scope='local')
-
-        if layer not in image_layers and not ref_image:
-            continue
-
-        image_url = image_layers.get(layer, None)
-        if image_url:
-            image, _ = image_tag_from_url(image_url)
-        else:
-            image = ref_image
-        if not image:
-            continue
-
-        if known_path and ref_image:
-            blob_path = known_path
-            image = ref_image
-            if ref_image != image:
-                LOG.debug('[%s] Layer ref. by image %s already exists '
-                          'at %s' % (image, ref_image, known_path))
-            else:
-                LOG.debug('[%s] Layer already exists at %s'
-                          % (image, known_path))
-        else:
-            dir_path = os.path.join(IMAGE_EXPORT_DIR, 'v2', image, 'blobs')
-            blob_path = os.path.join(dir_path, '%s.gz' % layer)
-            if not os.path.exists(blob_path):
-                LOG.debug('[%s] Layer not found: %s' % (image, blob_path))
-                continue
-
-        layer_cross_link(layer, image, blob_path, target_image_url)
-        linked_layers.update({layer: {'known_path': blob_path,
-                                      'ref_image': image}})
-    return linked_layers
-
-
 def export_manifest_config(target_url,
                            manifest_str,
                            manifest_type,
-                           config_str,
-                           multi_arch=False):
+                           config_str):
     image, tag = image_tag_from_url(target_url)
     manifest = json.loads(manifest_str)
     if config_str is not None:
@@ -253,43 +192,19 @@ def export_manifest_config(target_url,
         manifest_data = manifest_str.encode('utf-8')
         f.write(manifest_data)
 
-    manifest_dict = {}
-    if multi_arch:
-        if manifest_type == MEDIA_MANIFEST_V2_LIST:
-            manifest_dict[manifest_type] = manifest_digest
-            # choose one of the entries to be the default v2 manifest
-            # to return:
-            # - If architecture amd64 exists, choose that
-            # - Otherwise choose the first entry
-            entries = manifest.get('manifests')
-            if entries:
-                entry = None
-                for i in entries:
-                    if i.get('platform', {}).get('architecture') == 'amd64':
-                        entry = i
-                        break
-                if not entry:
-                    entry = entries[0]
-                manifest_dict[entry['mediaType']] = entry['digest']
-
-    else:
-        manifest_dict[manifest_type] = manifest_digest
-
-    if manifest_dict:
-        write_type_map_file(image, tag, manifest_dict)
+    write_type_map_file(image, tag, manifest_digest)
     build_tags_list(image)
 
 
-def write_type_map_file(image, tag, manifest_dict):
+def write_type_map_file(image, tag, manifest_digest):
     manifests_path = os.path.join(
         IMAGE_EXPORT_DIR, 'v2', image, 'manifests')
     type_map_path = os.path.join(manifests_path, '%s%s' %
                                  (tag, TYPE_MAP_EXTENSION))
     with open(type_map_path, 'w+') as f:
         f.write('URI: %s\n\n' % tag)
-        for manifest_type, digest in manifest_dict.items():
-            f.write('Content-Type: %s\n' % manifest_type)
-            f.write('URI: %s/index.json\n\n' % digest)
+        f.write('Content-Type: %s\n' % MEDIA_MANIFEST_V2)
+        f.write('URI: %s/index.json\n\n' % manifest_digest)
 
 
 def parse_type_map_file(type_map_path):
@@ -317,7 +232,7 @@ def migrate_to_type_map_file(image, manifest_symlink_path):
     tag = os.path.split(manifest_symlink_path)[-1]
     manifest_dir = os.readlink(manifest_symlink_path)
     manifest_digest = os.path.split(manifest_dir)[-1]
-    write_type_map_file(image, tag, {MEDIA_MANIFEST_V2: manifest_digest})
+    write_type_map_file(image, tag, manifest_digest)
     os.remove(manifest_symlink_path)
 
 
@@ -326,7 +241,7 @@ def build_tags_list(image):
         IMAGE_EXPORT_DIR, 'v2', image, 'manifests')
     tags_dir_path = os.path.join(IMAGE_EXPORT_DIR, 'v2', image, 'tags')
     tags_list_path = os.path.join(tags_dir_path, 'list')
-    LOG.debug('[%s] Rebuilding %s' % (image, tags_dir_path))
+    LOG.debug('Rebuilding %s' % tags_dir_path)
     make_dir(tags_dir_path)
     tags = []
     for f in os.listdir(manifests_path):
@@ -370,14 +285,13 @@ def delete_image(image_url):
 
     manifest_symlink_path = os.path.join(manifests_path, tag)
     if os.path.exists(manifest_symlink_path):
-        LOG.debug('[%s] Deleting legacy tag symlink %s' %
-                  (image, manifest_symlink_path))
+        LOG.debug('Deleting legacy tag symlink %s' % manifest_symlink_path)
         os.remove(manifest_symlink_path)
 
     type_map_path = os.path.join(manifests_path, '%s%s' %
                                  (tag, TYPE_MAP_EXTENSION))
     if os.path.exists(type_map_path):
-        LOG.debug('[%s] Deleting typemap file %s' % (image, type_map_path))
+        LOG.debug('Deleting typemap file %s' % type_map_path)
         os.remove(type_map_path)
 
     build_tags_list(image)
@@ -399,7 +313,7 @@ def delete_image(image_url):
 
     # delete list of manifest_dir_path without symlinks
     for manifest_dir in delete_manifest_dirs:
-        LOG.debug('[%s] Deleting manifest %s' % (image, manifest_dir))
+        LOG.debug('Deleting manifest %s' % manifest_dir)
         shutil.rmtree(manifest_dir)
 
     # load all remaining manifests and build the set of of in-use blobs,
@@ -433,14 +347,14 @@ def delete_image(image_url):
                      for b in os.listdir(blobs_path)])
     delete_blobs = all_blobs.difference(reffed_blobs)
     for blob in delete_blobs:
-        LOG.debug('[%s] Deleting layer blob %s' % (image, blob))
+        LOG.debug('Deleting layer blob %s' % blob)
         os.remove(blob)
 
     # if no files left in manifests_path, delete the whole image
     remaining = os.listdir(manifests_path)
     if not remaining or remaining == ['.htaccess']:
         image_path = os.path.join(IMAGE_EXPORT_DIR, 'v2', image)
-        LOG.debug('[%s] Deleting image directory %s' % (image, image_path))
+        LOG.debug('Deleting image directory %s' % image_path)
         shutil.rmtree(image_path)
 
     # rebuild the catalog for the current image list
