@@ -93,7 +93,7 @@ class TripleoInventory(object):
                  cacert=None, username=None, ansible_ssh_user=None,
                  host_network=None, ansible_python_interpreter=None,
                  undercloud_connection=UNDERCLOUD_CONNECTION_LOCAL,
-                 undercloud_key_file=None):
+                 undercloud_key_file=None, serial=1):
         self.session = session
         self.hclient = hclient
         self.hosts_format_dict = False
@@ -109,6 +109,7 @@ class TripleoInventory(object):
         self.stack_outputs = StackOutputs(self.plan_name, self.hclient)
         self.hostvars = {}
         self.undercloud_connection = undercloud_connection
+        self.serial = serial
 
     @staticmethod
     def get_roles_by_service(enabled_services):
@@ -134,9 +135,9 @@ class TripleoInventory(object):
             return {}
 
     UNDERCLOUD_SERVICES = [
-        'tripleo_nova_compute', 'tripleo_heat_engine',
-        'tripleo_ironic_conductor', 'tripleo_swift_container_server',
-        'tripleo_swift_object_server', 'tripleo_mistral_engine']
+        'openstack-nova-compute', 'openstack-heat-engine',
+        'openstack-ironic-conductor', 'openstack-swift-container',
+        'openstack-swift-object', 'openstack-mistral-engine']
 
     def get_undercloud_service_list(self):
         """Return list of undercloud services - currently static
@@ -221,9 +222,6 @@ class TripleoInventory(object):
                 shortnames = [n.split(".%s." % self.host_network)[0].lower()
                               for n in names]
                 ips = role_net_ip_map[role][self.host_network]
-                if not ips:
-                    raise Exception("No IPs found for %s role on %s network"
-                                    % (role, self.host_network))
                 hosts = {}
                 for idx, name in enumerate(shortnames):
                     hosts[name] = {}
@@ -259,6 +257,7 @@ class TripleoInventory(object):
                         'bootstrap_server_id': role_node_id_map.get(
                             'bootstrap_server_id'),
                         'tripleo_role_name': role,
+                        'serial': self.serial,
                     }
 
                 }
@@ -288,40 +287,18 @@ class TripleoInventory(object):
         # Associate services with roles
         roles_by_service = self.get_roles_by_service(
             self.stack_outputs.get('EnabledServices', {}))
-
-        # tripleo-groups map to ceph-ansible groups as follows
-        ceph_group_map = {
-            'ceph_mon': 'mons',
-            'ceph_osd': 'osds',
-            'ceph_mgr': 'mgrs',
-            'ceph_rgw': 'rgws',
-            'ceph_mds': 'mdss',
-            'ceph_nfs': 'nfss',
-            'ceph_client': 'clients',
-            'ceph_rbdmirror': 'rbdmirrors'
-        }
-        # add a ceph-ansible compatible group to the inventory
-        # which has the same roles. E.g. if the inventory has
-        # a group 'ceph_mon' which has childen and vars, then
-        # the inventory will now also have a group 'mons' with
-        # the same children and vars.
-        for service, roles in roles_by_service.copy().items():
-            if service in ceph_group_map.keys():
-                roles_by_service[ceph_group_map[service]] = roles
-
         for service, roles in roles_by_service.items():
             service_children = [role for role in roles
                                 if ret.get(role) is not None]
             if service_children:
-                svc_host = service.lower()
-                ret[svc_host] = {
+                ret[service.lower()] = {
                     'children': self._hosts(service_children),
                     'vars': {
                         'ansible_ssh_user': self.ansible_ssh_user
                     }
                 }
                 if self.ansible_python_interpreter:
-                    ret[svc_host]['vars']['ansible_python_interpreter'] = \
+                    ret[role]['vars']['ansible_python_interpreter'] = \
                         self.ansible_python_interpreter
 
         if not self.hosts_format_dict:
