@@ -16,6 +16,7 @@
 
 import mock
 import os
+import requests
 import six
 import sys
 import tempfile
@@ -39,20 +40,20 @@ kb.init_prepare_defaults(DEFAULTS_PATH)
 
 
 filedata = six.u("""container_images:
-- imagename: docker.io/tripleostein/heat-docker-agents-centos:latest
+- imagename: docker.io/tripleomaster/heat-docker-agents-centos:latest
   image_source: kolla
   push_destination: localhost:8787
-- imagename: docker.io/tripleostein/centos-binary-nova-compute:liberty
+- imagename: docker.io/tripleomaster/centos-binary-nova-compute:liberty
   image_source: kolla
   uploader: docker
   push_destination: localhost:8787
-- imagename: docker.io/tripleostein/centos-binary-nova-libvirt:liberty
+- imagename: docker.io/tripleomaster/centos-binary-nova-libvirt:liberty
   image_source: kolla
   uploader: docker
-- imagename: docker.io/tripleostein/image-with-missing-tag
+- imagename: docker.io/tripleomaster/image-with-missing-tag
   image_source: kolla
   push_destination: localhost:8787
-- imagename: docker.io/tripleostein/skip-build
+- imagename: docker.io/tripleomaster/skip-build
   image_source: foo
   push_destination: localhost:8787
 """)
@@ -233,10 +234,10 @@ class TestKollaImageBuilderTemplate(base.TestCase):
 
         self.assertEqual(
             {
-                'namespace': 'docker.io/tripleostein',
+                'namespace': 'docker.io/tripleomaster',
                 'ceph_namespace': 'docker.io/ceph',
                 'ceph_image': 'daemon',
-                'ceph_tag': 'v4.0.4-stable-4.0-nautilus-centos-7-x86_64',
+                'ceph_tag': 'v4.0.0-stable-4.0-nautilus-centos-7-x86_64',
                 'name_prefix': 'centos-binary-',
                 'name_suffix': '',
                 'tag': 'current-tripleo',
@@ -293,7 +294,7 @@ class TestKollaImageBuilderTemplate(base.TestCase):
 
         self.assertEqual(
             {
-                'namespace': '192.0.2.0:5000/tripleostein',
+                'namespace': '192.0.2.0:5000/tripleomaster',
                 'ceph_namespace': 'docker.io/cephh',
                 'ceph_image': 'ceph-daemon',
                 'ceph_tag': 'latest',
@@ -359,7 +360,7 @@ class TestKollaImageBuilderTemplate(base.TestCase):
                 'openshift_grafana_tag': 'v3.11',
             },
             builder.container_images_template_inputs(
-                namespace='192.0.2.0:5000/tripleostein',
+                namespace='192.0.2.0:5000/tripleomaster',
                 ceph_namespace='docker.io/cephh',
                 ceph_image='ceph-daemon',
                 ceph_tag='latest',
@@ -442,23 +443,23 @@ class TestKollaImageBuilderTemplate(base.TestCase):
         )
         container_images = [{
             'image_source': 'kolla',
-            'imagename': 'docker.io/tripleostein/'
+            'imagename': 'docker.io/tripleomaster/'
                          'centos-binary-nova-compute:liberty',
             'push_destination': 'localhost:8787',
             'uploader': 'docker'
         }, {
             'image_source': 'kolla',
-            'imagename': 'docker.io/tripleostein/'
+            'imagename': 'docker.io/tripleomaster/'
                          'centos-binary-nova-libvirt:liberty',
             'push_destination': 'localhost:8787',
             'uploader': 'docker'
         }, {
             'image_source': 'kolla',
-            'imagename': 'docker.io/tripleostein/image-with-missing-tag',
+            'imagename': 'docker.io/tripleomaster/image-with-missing-tag',
             'push_destination': 'localhost:8787'
         }, {
             'image_source': 'foo',
-            'imagename': 'docker.io/tripleostein/skip-build',
+            'imagename': 'docker.io/tripleomaster/skip-build',
             'push_destination': 'localhost:8787'
         }]
         self.assertEqual(container_images, result)
@@ -501,28 +502,28 @@ class TestKollaImageBuilderTemplate(base.TestCase):
     def test_container_images_yaml_in_sync(self):
         remove_images = [
             {'image_source': 'kolla',
-             'imagename': 'docker.io/tripleostein/centos-binary'
+             'imagename': 'docker.io/tripleomaster/centos-binary'
                           '-neutron-server-opendaylight:current-tripleo'},
             {'image_source': 'kolla',
-             'imagename': 'docker.io/tripleostein/centos-binary'
+             'imagename': 'docker.io/tripleomaster/centos-binary'
                           '-neutron-server-ovn:current-tripleo'},
             {'image_source': 'kolla',
-             'imagename': 'docker.io/tripleostein/centos-binary'
+             'imagename': 'docker.io/tripleomaster/centos-binary'
                           '-opendaylight:current-tripleo'},
             {'image_source': 'kolla',
-             'imagename': 'docker.io/tripleostein/centos-binary'
+             'imagename': 'docker.io/tripleomaster/centos-binary'
                           '-ovn-northd:current-tripleo'},
             {'image_source': 'kolla',
-             'imagename': 'docker.io/tripleostein/centos-binary-ovn-'
+             'imagename': 'docker.io/tripleomaster/centos-binary-ovn-'
                           'controller:current-tripleo'},
             {'image_source': 'kolla',
-             'imagename': 'docker.io/tripleostein/centos-binary-ovn-'
+             'imagename': 'docker.io/tripleomaster/centos-binary-ovn-'
                           'nb-db-server:current-tripleo'},
             {'image_source': 'kolla',
-             'imagename': 'docker.io/tripleostein/centos-binary-ovn-'
+             'imagename': 'docker.io/tripleomaster/centos-binary-ovn-'
                           'sb-db-server:current-tripleo'},
             {'image_source': 'kolla',
-             'imagename': 'docker.io/tripleostein/centos-binary'
+             'imagename': 'docker.io/tripleomaster/centos-binary'
                           '-neutron-metadata-agent-ovn:current-tripleo'}]
         self._test_container_images_yaml_in_sync_helper(
             remove_images=remove_images)
@@ -531,25 +532,25 @@ class TestKollaImageBuilderTemplate(base.TestCase):
         # remove neutron-server image reference from overcloud_containers.yaml
         remove_images = [
             {'image_source': 'kolla',
-             'imagename': 'docker.io/tripleostein/centos-binary'
+             'imagename': 'docker.io/tripleomaster/centos-binary'
                           '-neutron-server:current-tripleo'},
             {'image_source': 'kolla',
-             'imagename': 'docker.io/tripleostein/centos-binary'
+             'imagename': 'docker.io/tripleomaster/centos-binary'
                           '-neutron-server-ovn:current-tripleo'},
             {'image_source': 'kolla',
-             'imagename': 'docker.io/tripleostein/centos-binary'
+             'imagename': 'docker.io/tripleomaster/centos-binary'
                           '-ovn-northd:current-tripleo'},
             {'image_source': 'kolla',
-             'imagename': 'docker.io/tripleostein/centos-binary-ovn-'
+             'imagename': 'docker.io/tripleomaster/centos-binary-ovn-'
                           'controller:current-tripleo'},
             {'image_source': 'kolla',
-             'imagename': 'docker.io/tripleostein/centos-binary-ovn-'
+             'imagename': 'docker.io/tripleomaster/centos-binary-ovn-'
                           'nb-db-server:current-tripleo'},
             {'image_source': 'kolla',
-             'imagename': 'docker.io/tripleostein/centos-binary-ovn-'
+             'imagename': 'docker.io/tripleomaster/centos-binary-ovn-'
                           'sb-db-server:current-tripleo'},
             {'image_source': 'kolla',
-             'imagename': 'docker.io/tripleostein/centos-binary'
+             'imagename': 'docker.io/tripleomaster/centos-binary'
                           '-neutron-metadata-agent-ovn:current-tripleo'}]
         self._test_container_images_yaml_in_sync_helper(
             neutron_driver='odl', remove_images=remove_images)
@@ -558,13 +559,13 @@ class TestKollaImageBuilderTemplate(base.TestCase):
         # remove neutron-server image reference from overcloud_containers.yaml
         remove_images = [
             {'image_source': 'kolla',
-             'imagename': 'docker.io/tripleostein/centos-binary'
+             'imagename': 'docker.io/tripleomaster/centos-binary'
                           '-neutron-server:current-tripleo'},
             {'image_source': 'kolla',
-             'imagename': 'docker.io/tripleostein/centos-binary'
+             'imagename': 'docker.io/tripleomaster/centos-binary'
                           '-neutron-server-opendaylight:current-tripleo'},
             {'image_source': 'kolla',
-             'imagename': 'docker.io/tripleostein/centos-binary'
+             'imagename': 'docker.io/tripleomaster/centos-binary'
                           '-opendaylight:current-tripleo'}]
         self._test_container_images_yaml_in_sync_helper(
             neutron_driver='ovn', remove_images=remove_images)
@@ -581,25 +582,37 @@ class TestPrepare(base.TestCase):
             with open(imagefile.name, 'w') as f:
                 f.write(template_filedata)
 
-    @mock.patch.object(image_uploader.ImageUploadManager, 'uploader')
-    def test_detect_insecure_registry(self, mock_uploader):
-        mock_f = mock.MagicMock()
-        mock_f.is_insecure_registry.side_effect = [False, True]
-        mock_uploader.return_value = mock_f
+    @mock.patch('requests.get')
+    def test_detect_insecure_registry(self, mock_get):
         self.assertEqual(
             {},
             kb.detect_insecure_registries(
                 {'foo': 'docker.io/tripleo'}))
         self.assertEqual(
-            {'DockerInsecureRegistryAddress': ['tripleo']},
+            {},
             kb.detect_insecure_registries(
                 {'foo': 'tripleo'}))
 
-    @mock.patch.object(image_uploader.ImageUploadManager, 'uploader')
-    def test_detect_insecure_registry_multi(self, mock_uploader):
-        mock_f = mock.MagicMock()
-        mock_f.is_insecure_registry.return_value = True
-        mock_uploader.return_value = mock_f
+    @mock.patch('requests.get')
+    def test_detect_insecure_registry_readtimeout(self, mock_get):
+
+        mock_get.side_effect = requests.exceptions.ReadTimeout('ouch')
+        self.assertEqual(
+            {},
+            kb.detect_insecure_registries(
+                {'foo': '192.0.2.0:8787/tripleo'}))
+
+    @mock.patch('requests.get')
+    def test_detect_insecure_registry_sslerror(self, mock_get):
+        mock_get.side_effect = requests.exceptions.SSLError('ouch')
+        self.assertEqual(
+            {'DockerInsecureRegistryAddress': ['192.0.2.0:8787']},
+            kb.detect_insecure_registries(
+                {'foo': '192.0.2.0:8787/tripleo'}))
+
+    @mock.patch('requests.get')
+    def test_detect_insecure_registry_multi(self, mock_get):
+        mock_get.side_effect = requests.exceptions.SSLError('ouch')
         self.assertEqual(
             {'DockerInsecureRegistryAddress': [
                 '192.0.2.0:8787',
@@ -610,17 +623,15 @@ class TestPrepare(base.TestCase):
                 'baz': '192.0.2.1:8787/tripleo/baz',
             }))
 
-    @mock.patch('tripleo_common.image.kolla_builder.'
-                'detect_insecure_registries', return_value={})
-    def test_prepare_noargs(self, mock_insecure):
+    @mock.patch('requests.get')
+    def test_prepare_noargs(self, mock_get):
         self.assertEqual(
             {},
             kb.container_images_prepare(template_file=TEMPLATE_PATH)
         )
 
-    @mock.patch('tripleo_common.image.kolla_builder.'
-                'detect_insecure_registries', return_value={})
-    def test_prepare_simple(self, mock_insecure):
+    @mock.patch('requests.get')
+    def test_prepare_simple(self, mock_get):
         self.assertEqual({
             'container_images.yaml': [
                 {'image_source': 'kolla',
@@ -646,9 +657,8 @@ class TestPrepare(base.TestCase):
             )
         )
 
-    @mock.patch('tripleo_common.image.kolla_builder.'
-                'detect_insecure_registries', return_value={})
-    def test_prepare_includes(self, mock_insecure):
+    @mock.patch('requests.get')
+    def test_prepare_includes(self, mock_get):
         self.assertEqual({
             'container_images.yaml': [
                 {'image_source': 'kolla',
@@ -671,9 +681,8 @@ class TestPrepare(base.TestCase):
             )
         )
 
-    @mock.patch('tripleo_common.image.kolla_builder.'
-                'detect_insecure_registries', return_value={})
-    def test_prepare_includes_excludes(self, mock_insecure):
+    @mock.patch('requests.get')
+    def test_prepare_includes_excludes(self, mock_get):
         # assert same result as includes only. includes trumps excludes
         self.assertEqual({
             'container_images.yaml': [
@@ -698,9 +707,8 @@ class TestPrepare(base.TestCase):
             )
         )
 
-    @mock.patch('tripleo_common.image.kolla_builder.'
-                'detect_insecure_registries', return_value={})
-    def test_prepare_push_dest(self, mock_insecure):
+    @mock.patch('requests.get')
+    def test_prepare_push_dest(self, mock_get):
         self.assertEqual({
             'container_images.yaml': [{
                 'image_source': 'kolla',
@@ -732,10 +740,9 @@ class TestPrepare(base.TestCase):
             )
         )
 
-    @mock.patch('tripleo_common.image.kolla_builder.'
-                'detect_insecure_registries', return_value={})
+    @mock.patch('requests.get')
     @mock.patch('tripleo_common.image.image_uploader.get_undercloud_registry')
-    def test_prepare_push_dest_discover(self, mock_gur, mock_insecure):
+    def test_prepare_push_dest_discover(self, mock_gur, mock_get):
         mock_gur.return_value = '192.0.2.0:8787'
         self.assertEqual({
             'container_images.yaml': [{
@@ -768,9 +775,8 @@ class TestPrepare(base.TestCase):
             )
         )
 
-    @mock.patch('tripleo_common.image.kolla_builder.'
-                'detect_insecure_registries', return_value={})
-    def test_prepare_ceph(self, mock_insecure):
+    @mock.patch('requests.get')
+    def test_prepare_ceph(self, mock_get):
         self.assertEqual({
             'container_images.yaml': [{
                 'image_source': 'ceph',
@@ -792,9 +798,8 @@ class TestPrepare(base.TestCase):
             )
         )
 
-    @mock.patch('tripleo_common.image.kolla_builder.'
-                'detect_insecure_registries', return_value={})
-    def test_prepare_neutron_driver_default(self, mock_insecure):
+    @mock.patch('requests.get')
+    def test_prepare_neutron_driver_default(self, mock_get):
         self.assertEqual({
             'container_images.yaml': [
                 {'image_source': 'kolla',
@@ -821,9 +826,8 @@ class TestPrepare(base.TestCase):
             )
         )
 
-    @mock.patch('tripleo_common.image.kolla_builder.'
-                'detect_insecure_registries', return_value={})
-    def test_prepare_neutron_driver_ovn(self, mock_insecure):
+    @mock.patch('requests.get')
+    def test_prepare_neutron_driver_ovn(self, mock_get):
         self.assertEqual({
             'container_images.yaml': [
                 {'image_source': 'kolla',
@@ -855,9 +859,8 @@ class TestPrepare(base.TestCase):
             )
         )
 
-    @mock.patch('tripleo_common.image.kolla_builder.'
-                'detect_insecure_registries', return_value={})
-    def test_prepare_neutron_driver_odl(self, mock_insecure):
+    @mock.patch('requests.get')
+    def test_prepare_neutron_driver_odl(self, mock_get):
         self.assertEqual({
             'container_images.yaml': [
                 {'image_source': 'kolla',
@@ -1026,7 +1029,6 @@ class TestPrepare(base.TestCase):
     @mock.patch('tripleo_common.image.image_uploader.ImageUploadManager',
                 autospec=True)
     def test_container_images_prepare_multi(self, mock_im, mock_cip):
-        mock_lock = mock.MagicMock()
         mapping_args = {
             'namespace': 't',
             'name_prefix': '',
@@ -1080,8 +1082,7 @@ class TestPrepare(base.TestCase):
             },
         ]
 
-        image_params = kb.container_images_prepare_multi(env, roles_data,
-                                                         lock=mock_lock)
+        image_params = kb.container_images_prepare_multi(env, roles_data)
 
         mock_cip.assert_has_calls([
             mock.call(
@@ -1104,8 +1105,7 @@ class TestPrepare(base.TestCase):
                 registry_credentials={
                     'docker.io': {'my_username': 'my_password'}
                 },
-                multi_arch=False,
-                lock=mock_lock
+                multi_arch=False
             ),
             mock.call(
                 excludes=['nova', 'neutron'],
@@ -1127,8 +1127,7 @@ class TestPrepare(base.TestCase):
                 registry_credentials={
                     'docker.io': {'my_username': 'my_password'}
                 },
-                multi_arch=False,
-                lock=mock_lock
+                multi_arch=False
             )
         ])
 
@@ -1148,7 +1147,6 @@ class TestPrepare(base.TestCase):
     @mock.patch('tripleo_common.image.image_uploader.ImageUploadManager',
                 autospec=True)
     def test_container_images_prepare_multi_dry_run(self, mock_im, mock_cip):
-        mock_lock = mock.MagicMock()
         mapping_args = {
             'namespace': 't',
             'name_prefix': '',
@@ -1197,8 +1195,7 @@ class TestPrepare(base.TestCase):
             },
         ]
 
-        image_params = kb.container_images_prepare_multi(env, roles_data, True,
-                                                         lock=mock_lock)
+        image_params = kb.container_images_prepare_multi(env, roles_data, True)
 
         mock_cip.assert_has_calls([
             mock.call(
@@ -1217,8 +1214,7 @@ class TestPrepare(base.TestCase):
                 modify_vars=None,
                 mirrors={},
                 registry_credentials=None,
-                multi_arch=False,
-                lock=mock_lock
+                multi_arch=False
             ),
             mock.call(
                 excludes=['nova', 'neutron'],
@@ -1236,14 +1232,13 @@ class TestPrepare(base.TestCase):
                 modify_vars={'foo_version': '1.0.1'},
                 mirrors={},
                 registry_credentials=None,
-                multi_arch=False,
-                lock=mock_lock
+                multi_arch=False
             )
         ])
 
         mock_im.assert_called_once_with(mock.ANY, dry_run=True, cleanup='full',
                                         mirrors={}, registry_credentials=None,
-                                        multi_arch=False, lock=mock_lock)
+                                        multi_arch=False)
 
         self.assertEqual(
             {
