@@ -39,8 +39,7 @@ MOCK_ENABLED_SERVICES = {
     "Compute": [
         "nova_compute",
         "kernel",
-        "tripleo_packages",
-        "ceph_client"
+        "tripleo_packages"
     ],
     "CephStorage": [
         "kernel",
@@ -61,7 +60,7 @@ class TestInventory(base.TestCase):
             {'output_key': 'EnabledServices',
              'output_value': {
                  'Controller': ['sa', 'sb'],
-                 'Compute': ['sd', 'se', 'ceph_client'],
+                 'Compute': ['sd', 'se'],
                  'CustomRole': ['sg', 'sh']}},
             {'output_key': 'KeystoneURL',
              'output_value': 'xyz://keystone'},
@@ -139,7 +138,6 @@ class TestInventory(base.TestCase):
             'keystone': ['Controller'],
             'nova_compute': ['Compute'],
             'cinder_volume': ['BlockStorage'],
-            'ceph_client': ['Compute'],
         }
         self.assertDictEqual(services, expected)
 
@@ -158,12 +156,6 @@ class TestInventory(base.TestCase):
         self.assertTrue(self.hclient.called_once_with('overcloud',
                                                       'KeystoneURL'))
 
-    def test_no_ips(self):
-        for output in self.outputs_data['outputs']:
-            if output['output_key'] == 'RoleNetIpMap':
-                output['output_value'] = dict(Controller=dict(ctlplane=[]))
-        self.assertRaises(Exception, self.inventory.list)  # noqa: H202
-
     def test_outputs_invalid_key_raises_keyerror(self):
         self.assertRaises(KeyError, lambda: self.outputs['Invalid'])
 
@@ -189,16 +181,19 @@ class TestInventory(base.TestCase):
                 'hosts': ['cp-0'],
                 'vars': {'ansible_ssh_user': ansible_ssh_user,
                          'bootstrap_server_id': 'a',
+                         'serial': 1,
                          'tripleo_role_name': 'Compute'}},
             'Controller': {
                 'hosts': ['c-0', 'c-1', 'c-2'],
                 'vars': {'ansible_ssh_user': ansible_ssh_user,
                          'bootstrap_server_id': 'a',
+                         'serial': 1,
                          'tripleo_role_name': 'Controller'}},
             'CustomRole': {
                 'hosts': ['cs-0'],
                 'vars': {'ansible_ssh_user': ansible_ssh_user,
                          'bootstrap_server_id': 'a',
+                         'serial': 1,
                          'tripleo_role_name': 'CustomRole'}},
 
             'overcloud': {
@@ -221,12 +216,12 @@ class TestInventory(base.TestCase):
                          'plan': 'overcloud',
                          'project_name': 'admin',
                          'undercloud_service_list': [
-                             'tripleo_nova_compute',
-                             'tripleo_heat_engine',
-                             'tripleo_ironic_conductor',
-                             'tripleo_swift_container_server',
-                             'tripleo_swift_object_server',
-                             'tripleo_mistral_engine'],
+                             'openstack-nova-compute',
+                             'openstack-heat-engine',
+                             'openstack-ironic-conductor',
+                             'openstack-swift-container',
+                             'openstack-swift-object',
+                             'openstack-mistral-engine'],
                          'undercloud_swift_url': 'anendpoint',
                          'username': 'admin'}}}
         inv_list = inventory.list()
@@ -269,18 +264,21 @@ class TestInventory(base.TestCase):
                 'vars': {'ansible_python_interpreter': 'foo',
                          'ansible_ssh_user': ansible_ssh_user,
                          'bootstrap_server_id': 'a',
+                         'serial': 1,
                          'tripleo_role_name': 'Compute'}},
             'Controller': {
                 'hosts': ['c-0', 'c-1', 'c-2'],
                 'vars': {'ansible_python_interpreter': 'foo',
                          'ansible_ssh_user': ansible_ssh_user,
                          'bootstrap_server_id': 'a',
+                         'serial': 1,
                          'tripleo_role_name': 'Controller'}},
             'CustomRole': {
                 'hosts': ['cs-0'],
                 'vars': {'ansible_python_interpreter': 'foo',
                          'ansible_ssh_user': ansible_ssh_user,
                          'bootstrap_server_id': 'a',
+                         'serial': 1,
                          'tripleo_role_name': 'CustomRole'}},
             'overcloud': {
                 'children': ['Compute', 'Controller', 'CustomRole'],
@@ -288,24 +286,6 @@ class TestInventory(base.TestCase):
                     'container_cli': 'podman',
                     'ctlplane_vip': 'x.x.x.4',
                     'redis_vip': 'x.x.x.6'}},
-            'sa': {'children': ['Controller'],
-                   'vars': {'ansible_ssh_user': 'my-custom-admin',
-                            'ansible_python_interpreter': 'foo'}},
-            'sb': {'children': ['Controller'],
-                   'vars': {'ansible_ssh_user': 'my-custom-admin',
-                            'ansible_python_interpreter': 'foo'}},
-            'sd': {'children': ['Compute'],
-                   'vars': {'ansible_ssh_user': 'my-custom-admin',
-                            'ansible_python_interpreter': 'foo'}},
-            'se': {'children': ['Compute'],
-                   'vars': {'ansible_ssh_user': 'my-custom-admin',
-                            'ansible_python_interpreter': 'foo'}},
-            'sg': {'children': ['CustomRole'],
-                   'vars': {'ansible_ssh_user': 'my-custom-admin',
-                            'ansible_python_interpreter': 'foo'}},
-            'sh': {'children': ['CustomRole'],
-                   'vars': {'ansible_ssh_user': 'my-custom-admin',
-                            'ansible_python_interpreter': 'foo'}},
             'Undercloud': {
                 'hosts': ['undercloud'],
                 'vars': {'ansible_connection': 'ssh',
@@ -323,12 +303,12 @@ class TestInventory(base.TestCase):
                          'plan': 'overcloud',
                          'project_name': 'admin',
                          'undercloud_service_list': [
-                             'tripleo_nova_compute',
-                             'tripleo_heat_engine',
-                             'tripleo_ironic_conductor',
-                             'tripleo_swift_container_server',
-                             'tripleo_swift_object_server',
-                             'tripleo_mistral_engine'],
+                             'openstack-nova-compute',
+                             'openstack-heat-engine',
+                             'openstack-ironic-conductor',
+                             'openstack-swift-container',
+                             'openstack-swift-object',
+                             'openstack-mistral-engine'],
                          'undercloud_swift_url':
                          'anendpoint' if session else None,
                          'username': 'admin'}}}
@@ -361,6 +341,7 @@ class TestInventory(base.TestCase):
                         'enabled_networks': ['ctlplane']}},
                 'vars': {'ansible_ssh_user': ansible_ssh_user,
                          'bootstrap_server_id': 'a',
+                         'serial': 1,
                          'tripleo_role_name': 'Compute'}},
             'Controller': {
                 'hosts': {
@@ -381,6 +362,7 @@ class TestInventory(base.TestCase):
                         'enabled_networks': ['ctlplane']}},
                 'vars': {'ansible_ssh_user': ansible_ssh_user,
                          'bootstrap_server_id': 'a',
+                         'serial': 1,
                          'tripleo_role_name': 'Controller'}},
             'CustomRole': {
                 'hosts': {
@@ -391,6 +373,7 @@ class TestInventory(base.TestCase):
                         'enabled_networks': ['ctlplane']}},
                 'vars': {'ansible_ssh_user': ansible_ssh_user,
                          'bootstrap_server_id': 'a',
+                         'serial': 1,
                          'tripleo_role_name': 'CustomRole'}},
             'overcloud': {'children': {'Compute': {},
                                        'Controller': {},
@@ -406,10 +389,6 @@ class TestInventory(base.TestCase):
                    'vars': {'ansible_ssh_user': 'heat-admin'}},
             'se': {'children': {'Compute': {}},
                    'vars': {'ansible_ssh_user': 'heat-admin'}},
-            'ceph_client': {'children': {'Compute': {}},
-                            'vars': {'ansible_ssh_user': 'heat-admin'}},
-            'clients': {'children': {'Compute': {}},
-                        'vars': {'ansible_ssh_user': 'heat-admin'}},
             'sg': {'children': {'CustomRole': {}},
                    'vars': {'ansible_ssh_user': 'heat-admin'}},
             'sh': {'children': {'CustomRole': {}},
@@ -429,12 +408,12 @@ class TestInventory(base.TestCase):
                                     'plan': 'overcloud',
                                     'project_name': 'admin',
                                     'undercloud_service_list': [
-                                        'tripleo_nova_compute',
-                                        'tripleo_heat_engine',
-                                        'tripleo_ironic_conductor',
-                                        'tripleo_swift_container_server',
-                                        'tripleo_swift_object_server',
-                                        'tripleo_mistral_engine'],
+                                        'openstack-nova-compute',
+                                        'openstack-heat-engine',
+                                        'openstack-ironic-conductor',
+                                        'openstack-swift-container',
+                                        'openstack-swift-object',
+                                        'openstack-mistral-engine'],
                                     'undercloud_swift_url': 'anendpoint',
                                     'username': 'admin'}}}
         if extra_vars:
