@@ -64,6 +64,10 @@ def download_container(swiftclient, container, dest,
         is_newer = False
         filename = obj['name']
         contents = swiftclient.get_object(container, filename)[1]
+        try:
+            contents = contents.encode('utf-8')
+        except (UnicodeDecodeError, AttributeError):
+            pass
         path = os.path.join(dest, filename)
         dirname = os.path.dirname(path)
         already_exists = os.path.exists(path)
@@ -89,7 +93,9 @@ def download_container(swiftclient, container, dest,
             if not os.path.exists(dirname):
                 os.makedirs(dirname)
 
-            with open(path, 'w') as f:
+            # open in binary as the swift client returns error
+            # under python3 if opened as text
+            with open(path, 'wb') as f:
                 f.write(contents)
 
 
@@ -166,3 +172,21 @@ def create_and_upload_tarball(swiftservice,
                         LOG.error("%s" % error)
     except SwiftError as e:
         LOG.error(e.value)
+
+
+def get_object_string(swift, container, object_name):
+    """Get the object contents as a string """
+    data = swift.get_object(container, object_name)[1]
+    try:
+        return data.decode('utf-8')
+    except AttributeError:
+        return data
+
+
+def put_object_string(swift, container, object_name, contents):
+    """Put the object contents as a string """
+    try:
+        contents = contents.decode('utf-8')
+    except AttributeError:
+        pass
+    return swift.put_object(container, object_name, contents)
